@@ -30,7 +30,7 @@ use Carp;
 use File::Temp;
 use Shell::GetEnv::Dumper;
 
-our $VERSION = '0.08_01';
+our $VERSION = '0.08_02';
 
 
 # a compendium of shells
@@ -42,6 +42,13 @@ my %shells = (
 		       Echo      => 'x',
 		      },
 
+	      zsh => {
+		       Interactive     => 'i',
+		       NoStartup => 'p',
+		       Verbose   => 'v',
+		       Echo      => 'x',
+		      },
+
 	      dash => {
 		       Interactive     => 'i',
 		       Verbose   => 'v',
@@ -371,7 +378,7 @@ sub envs
 
     if ( $opt{EnvStr} )
     {
-	my @set = map { "$_=" . _shell_escape($env{$_}) } keys %env;
+	my @set = map { _shell_escape("$_=" . $env{$_}) } keys %env;
 	my @unset;
 
 	if ( $opt{ZapDeleted} )
